//
// Copyright (c) 1996 Vermeer Technologies, Inc., a wholly owned
//               subsidiary of Microsoft Corp.  All Rights Reserved

// CDIBBtn : implementation file
//

#include "stdafx.h"

#ifndef __AFXWIN_H__
#include "afxwin.h"
#endif
#include "cdibbtn.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CDIBBtn

CDIBBtn::CDIBBtn()
{
	m_hDIB = NULL;
	m_bIsResource = FALSE;
}

CDIBBtn::~CDIBBtn()
{
	if(m_hDIB != NULL && !m_bIsResource)
		::GlobalFree(m_hDIB);
	m_hDIB = NULL;
}

CPalette *CDIBBtn::pGlobalPalette = NULL;

BEGIN_MESSAGE_MAP(CDIBBtn, CStatic)
	//{{AFX_MSG_MAP(CDIBBtn)
	ON_WM_PAINT()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CDIBBtn message handlers

void CDIBBtn::OnPaint() 
{
	CPaintDC dc(this); // device context for painting
	
	// get rect for the whole window
	CRect rect;
	GetClientRect(&rect);

	// set clipping region
	CRgn rgn;
	rgn.CreateRectRgnIndirect(&rect);
	dc.SelectClipRgn(&rgn);

	// draw the whole DIB
	CRect dibrect;
	dibrect.left = 0;
	dibrect.top = 0;
	dibrect.right = rect.right - rect.left;
	dibrect.bottom = rect.bottom - rect.top;

	PaintDIB(dc,&rect,m_hDIB,&dibrect,CDIBBtn::pGlobalPalette);

	// delete temp region
	rgn.DeleteObject();
}

// SizeToContent will resize us to the size of the DIB
void CDIBBtn::SizeToContent()
{
	if(m_hDIB == NULL || m_hWnd == NULL)
		return;
	BITMAPINFO *pbmInfo = NULL;
	if(m_bIsResource)
	   pbmInfo = (BITMAPINFO *) ::LockResource(m_hDIB);
	else
	   pbmInfo = (BITMAPINFO *) ::GlobalLock(m_hDIB);
	if(!pbmInfo)
	{
		TRACE0(_T("** SizeToContent() couldn't lock the DIB\n"));
		return;
	}
	
	SetWindowPos(NULL, -1, -1, 
		pbmInfo->bmiHeader.biWidth, 
		pbmInfo->bmiHeader.biHeight,
		SWP_NOMOVE|SWP_NOZORDER|SWP_NOREDRAW|SWP_NOACTIVATE);

	if(!m_bIsResource)
	  ::GlobalUnlock(m_hDIB);
}

BOOL CDIBBtn::SetDIB(int nResID)
{
	if(m_hDIB != NULL && !m_bIsResource)
		::GlobalFree(m_hDIB);
	m_hDIB = NULL;
	HDIB hdib = LoadDIBResource(nResID);
	if(hdib == NULL)
		return FALSE;
	m_hDIB = hdib;
	// m_bIsResource = TRUE;
	if(m_hWnd)
		Invalidate(FALSE);
	return TRUE;
}

BOOL CDIBBtn::SetDIB(LPCTSTR szFileName)
{
	if(m_hDIB != NULL && !m_bIsResource)
		::GlobalFree(m_hDIB);
	m_hDIB = NULL;
	CFile f;
	if(!f.Open(szFileName,CFile::modeRead | CFile::typeBinary))
		return FALSE;
	m_hDIB = ReadDIBFile(f);
	f.Close();
	// m_bIsResource = FALSE;
	if(m_hWnd)
		Invalidate(FALSE);
	return TRUE;
}






