//
// Copyright (c) 1996 Vermeer Technologies, Inc., a wholly owned
//               subsidiary of Microsoft Corp.  All Rights Reserved

// CCount class
//
// Encapsulates the locking, reading, incrementing, and unlocking of
// the count data file
#include "fpcount.h"

class CCount
{

    // Public Methods
public:
    // The constructor opens and locks the file, with a timeout of 10
    // seconds if the file is already locked by another process.
    // If the file doesn't exist, and "create" is true, then it 
    // creates the count file with a count of 0.
    CCount(const char *filename, BOOL create=FALSE);
    
    ~CCount();                        // closes and unlocks the file

    void Increment(long amount = 1);    // adds "amount" to the count
    void SetCount(long newCount);        // Sets the current count
    long GetCount();                    // Gets the current count

    // Private Data Members
private:
    long m_count;
    int fd;
    BOOL error;

    BOOL OpenAndLock(const char *filename, int nTimeoutSec, BOOL create);

    void Close();
    long ReadCount();
    void WriteCount(long count);
    BOOL IsValid();

};

// Key to identify a count file
#define KEY_STR "FPCountFile "
#define KEY_LEN 12
#define MAX_NUM 12                      // maximum length of a long
