//
// Copyright (c) 1996 Vermeer Technologies, Inc., a wholly owned
//               subsidiary of Microsoft Corp.  All Rights Reserved

// CNumberImage implementation

#include "numimage.h"
#include <math.h>
#include <stdlib.h>
#include <string.h>

CNumberImage::CNumberImage()
{
    m_numberImage = NULL;
    m_numberTemplate = NULL;
}

CNumberImage::~CNumberImage()
{
    if (m_numberImage)
        gdImageDestroy(m_numberImage);
    if (m_numberTemplate)
        gdImageDestroy(m_numberTemplate);
}

gdImagePtr CNumberImage::GetImage()
{
    return m_numberImage;
}


void CNumberImage::OutputImageAsGif(FILE *out)
{
    if (m_numberImage)
        gdImageGif(m_numberImage, out);
}


BOOL CNumberImage::CreateImage(istream &numeralTemplate, long number,
                                BOOL bUseFixedNumDigits, int nFixedDigits)
{
    m_numberTemplate = gdImageCreateFromGif(numeralTemplate);
    if (m_numberTemplate == NULL) return FALSE;
    
    // Round the digit width in case the image width is not a perfect
    // multiple of 10
    digitWidth = (int)floor(((double)(m_numberTemplate->sx)/10)+0.5);
    digitHeight = m_numberTemplate->sy;

    char buffer[33];        // character buffer
    sprintf(buffer, "%ld", number);    //Convert num to string
    int nDigitsInNumber = strlen(buffer);

    int i;                                        // dummy counter var
    // If we want a fixed number of digits, promote the number to
    // that many digits
    if (bUseFixedNumDigits)
    {
        int offset = nFixedDigits - nDigitsInNumber;
        if (offset > 0)
        {
            // Slide the number over 'offset' digits
            for (i=nDigitsInNumber-1; i>=0; i--)            
                buffer[i+offset] = buffer[i];
            // Pad with 0's
            for (i=offset-1; i>=0; i--)
                buffer[i] = '0';
        }
        else if (offset < 0)
        {
            // Need to truncate (roll over) the upper numbers
            for (i=-offset; i<nDigitsInNumber; i++)
                buffer[i+offset] = buffer[i];
        }
        nDigitsInNumber = nFixedDigits;
    }

    // Create a new image, width is number of digits times the width of each
    // and the height is the same height as the digits template image
    m_numberImage = gdImageCreate(digitWidth*nDigitsInNumber, digitHeight);
    if (m_numberImage == NULL) return FALSE;

    for (i=0; i<nDigitsInNumber; i++)    
        // Copy from the buffer[i] numeral in the template into the ith
        // position of the final image
        CopyNumber(buffer[i] - '0', i);
    return TRUE;
}


void CNumberImage::CopyNumber(int from, int to)
{
    // Copy from the "from"th entry of the template image to the "to"th
    // entry of the final image
    // uses gdImageCopy(gdImagePtr dst, gdImagePtr src, 
    //                    int dstX, int dstY, int srcX, int srcY, 
    //                    int w, int h);
    gdImageCopy(m_numberImage, m_numberTemplate,
                to*digitWidth, 0,
                from*digitWidth, 0,
                digitWidth, digitHeight);
}
